@@ -282,56 +282,6 @@ bonobo_window_key_release_event (GtkWidget *widget,
 	return GTK_WIDGET_CLASS (parent_class)->key_release_event (widget, event);
 }
 
-static gboolean
-bonobo_window_focus (GtkWidget        *widget,
-		     GtkDirectionType  direction)
-{
-  GtkWindow *window;
-  GtkContainer *container;
-  GtkWidget *old_focus_child;
-  GtkWidget *parent;
-  GtkWidget *child;
-  BonoboWindow *win = (BonoboWindow *) widget;
-
-  container = GTK_CONTAINER (widget);
-  window = GTK_WINDOW (widget);
-
-  old_focus_child = container->focus_child;
-  child = win->priv->dock ? bonobo_dock_get_client_area (win->priv->dock) : NULL;
-  
-  /* We need a special implementation here to deal properly with wrapping
-   * around in the tab chain without the danger of going into an
-   * infinite loop.
-   */
-  if (old_focus_child)
-    {
-      if (gtk_widget_child_focus (old_focus_child, direction))
-	return TRUE;
-    }
-
-  if (window->focus_widget)
-    {
-      /* Wrapped off the end, clear the focus setting for the toplpevel */
-      parent = window->focus_widget->parent;
-      while (parent)
-	{
-	  gtk_container_set_focus_child (GTK_CONTAINER (parent), NULL);
-	  parent = GTK_WIDGET (parent)->parent;
-	}
-      
-      gtk_window_set_focus (GTK_WINDOW (container), NULL);
-    }
-
-  /* Now try to focus the first widget in the window */
-  if (child)
-    {
-      if (gtk_widget_child_focus (child, direction))
-        return TRUE;
-    }
-
-  return FALSE;
-}
-
 static void
 bonobo_window_set_property (GObject         *object,
 			guint            prop_id,
@@ -385,7 +335,6 @@ bonobo_window_class_init (BonoboWindowClass *klass)
 	gobject_class->set_property = bonobo_window_set_property;
 	gobject_class->get_property = bonobo_window_get_property;
 
-	widget_class->focus = bonobo_window_focus;
 	widget_class->show_all = bonobo_window_show_all;
 	widget_class->key_press_event = bonobo_window_key_press_event;
 	widget_class->key_release_event = bonobo_window_key_release_event;
